==> haskell-record-dot-preprocessor-0.2.14-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-record-dot-preprocessor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 record-dot-preprocessor
version:              0.2.14
visibility:           public
id:                   record-dot-preprocessor-0.2.14-4SiFzbvtzbv7CO2dmNW6wt
key:                  record-dot-preprocessor-0.2.14-4SiFzbvtzbv7CO2dmNW6wt
license:              BSD-3-Clause
copyright:            Neil Mitchell 2018-2022
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:
    https://github.com/ndmitchell/record-dot-preprocessor#readme

synopsis:             Preprocessor to allow record.field syntax
description:
    In almost every programming language @a.b@ will get the @b@ field from the @a@ data type, and many different data types can have a @b@ field.
    The reason this feature is ubiquitous is because it'\''s /useful/.
    The @record-dot-preprocessor@ brings this feature to Haskell - see the README for full details.

category:             Development
abi:                  0b2a2a7c10bbae551b6b76ad7796e1bb
exposed:              True
exposed-modules:      RecordDotPreprocessor RecordDotPreprocessor.Lib
hidden-modules:       Compat Edit Lexer Paren
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.14

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.14

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-record-dot-preprocessor
hs-libraries:         HSrecord-dot-preprocessor-0.2.14-4SiFzbvtzbv7CO2dmNW6wt
depends:
    base-4.15.1.0 extra-1.7.10-Ftra9IdqTdp95PiG9UbAhf ghc-9.0.2
    uniplate-1.6.13-3yozqXhrstJ89BQh777zFh

haddock-interfaces:
    /usr/share/doc/haskell-record-dot-preprocessor/html/record-dot-preprocessor.haddock

haddock-html:         /usr/share/doc/haskell-record-dot-preprocessor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-record-dot-preprocessor-0.2.14-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-record-dot-preprocessor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 record-dot-preprocessor
version:              0.2.14
visibility:           public
id:                   record-dot-preprocessor-0.2.14-5uwpglKUJa24bANYxtq35r
key:                  record-dot-preprocessor-0.2.14-5uwpglKUJa24bANYxtq35r
license:              BSD-3-Clause
copyright:            Neil Mitchell 2018-2022
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:
    https://github.com/ndmitchell/record-dot-preprocessor#readme

synopsis:             Preprocessor to allow record.field syntax
description:
    In almost every programming language @a.b@ will get the @b@ field from the @a@ data type, and many different data types can have a @b@ field.
    The reason this feature is ubiquitous is because it'\''s /useful/.
    The @record-dot-preprocessor@ brings this feature to Haskell - see the README for full details.

category:             Development
abi:                  dd181e4711165cd008cad913d576c985
exposed:              True
exposed-modules:      RecordDotPreprocessor RecordDotPreprocessor.Lib
hidden-modules:       Compat Edit Lexer Paren
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.14

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/record-dot-preprocessor-0.2.14

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-record-dot-preprocessor
hs-libraries:         HSrecord-dot-preprocessor-0.2.14-5uwpglKUJa24bANYxtq35r
depends:
    base-4.15.1.0 extra-1.7.10-4alF0dzQOAkJknciclp0Xd ghc-9.0.2
    uniplate-1.6.13-HG9J2jcrUNzL5EfUewKWUJ

haddock-interfaces:
    /usr/share/doc/haskell-record-dot-preprocessor/html/record-dot-preprocessor.haddock

haddock-html:         /usr/share/doc/haskell-record-dot-preprocessor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
